@@ -3,6 +3,8 @@ import logging
 import os
 import pickle
 
+import pandas as pd
+
 import pyresdev.utils as utils
 import pyresdev.utils.data_engineering_functions as DEutils
 
@@ -32,7 +34,6 @@ def preprocessing_training_common(df, config, model_type, mapping_dicts=None, im
     df = (df.pipe(utils.reduce_mem_usage)
           .pipe(DEutils.set_dataframe_columntypes)
           .pipe(DEutils.clean_previous_status, status_to_clean=config['status_to_delete'])
-          .pipe(DEutils.clean_rows_with_na, cols_to_clean_na=config['cols_to_clean_na'])
           .pipe(DEutils.clean_companytype)
           .pipe(DEutils.fill_na_with_unknown, columns=config['fill_unknown'])
           .pipe(DEutils.create_company_years_column)
@@ -143,22 +144,40 @@ s
     return df_leads_clean, imp , mapping_dicts
 
 
-def preprocessing_predictions(df, imputer, mapping_dicts, config):
-    df = (df.pipe(DEutils.set_dataframe_columntypes)
-          .pipe(DEutils.clean_previous_status, status_to_clean=config['status_to_delete'])
-          .pipe(DEutils.clean_rows_with_na, cols_to_clean_na=config['cols_to_clean_na'])
+def preprocessing_predictions(df, imputer, mapping_dicts: dict, config: dict, training_sample,fill_value=0):
+    df = (df.pipe(utils.reduce_mem_usage).
+          pipe(DEutils.set_dataframe_columntypes)
           .pipe(DEutils.clean_companytype)
-          .pipe(DEutils.fill_na_with_unknown, columns=config['fill_unknown'])
+          .pipe(DEutils.fill_na_with_unknown,
+                columns=config['fill_unknown'])
           .pipe(DEutils.create_company_years_column)
           .pipe(DEutils.fill_seniority_column)
-          .pipe(DEutils.filter_countries)
           .pipe(DEutils.clean_companyfollowers_text)
+          .pipe(DEutils.filter_countries)
           .pipe(DEutils.convert_kwkey_specialties_and_technologies_to_int)
           .pipe(DEutils.fill_variables)
           .pipe(DEutils.impute_growth)
+          .pipe(DEutils.impute_nas,
+                columns_to_impute=config['impute_columns'],
+                imp=imputer)
           .pipe(DEutils.log_transformation, columns=config['cols_to_transform'])
-          .pipe(DEutils.drop_columns, columns=config['cols_to_drop'][model_type])
-          .pipe(DEutils.correct_C80_success_code)
+          .pipe(DEutils.map_conv_prob_using_dictionary,
+                mapping_dicts['mx_prob'],
+                mapping_dicts['mx_bv'],
+                'MXType')
+          .pipe(DEutils.map_conv_prob_using_dictionary,
+                mapping_dicts['state_prob'],
+                mapping_dicts['state_bv'],
+                'State')
+          .pipe(DEutils.map_conv_prob_using_dictionary,
+                mapping_dicts['industry_prob'],
+                mapping_dicts['industry_bv'],
+                'Industry')
+          .pipe(DEutils.drop_columns, columns=config['cols_to_drop'])
+          .pipe(utils.reduce_mem_usage_category)
+          .pipe(DEutils.one_hot_encoding)
+          .pipe(DEutils.align_dataframe_with_sample,
+                training_sample,
+                fill_value)
           )
-
     return df
