@@ -132,6 +132,15 @@ def one_hot_encoding(df):
     logging.info(f"{df.dtypes}")
     return df
 
+def align_dataframe_with_sample(df,sample, fillvalue=0):
+    logger.info('aligning dataframe with sample')
+    _,df = sample.align(
+        df,
+        join='left',
+        axis=1,
+        fill_value=fillvalue
+    )
+    return df
 
 def convert_date(df):
     # Convert date
